@@ -6,10 +6,10 @@ use 5.020;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 Travel::Status::DE::DBRIS::Location->mk_ro_accessors(
-	qw(eva id lat lon name products type is_cancelled is_additional is_separation display_priority
+	qw(eva id lat lon name admin_id products type is_cancelled is_additional is_separation display_priority
 	  dep arr sched_dep sched_arr rt_dep rt_arr arr_delay dep_delay delay
 	  platform sched_platform rt_platform
 	  occupancy_first occupancy_second occupancy
@@ -73,6 +73,10 @@ sub new {
 
 	$ref->{delay} = $ref->{arr_delay} // $ref->{dep_delay};
 
+	if ( $json->{adminID} ) {
+		$ref->{admin_id} = $json->{adminID};
+	}
+
 	for my $occupancy ( @{ $json->{auslastungsmeldungen} // [] } ) {
 		if ( $occupancy->{klasse} eq 'KLASSE_1' ) {
 			$ref->{occupancy_first} = $occupancy->{stufe};
